
.. currentmodule:: nilearn

.. include:: names.rst

0.2.4
=====

**Released April 2016**

The ``0.2.4`` is a small release focused on documentation for teaching.

New
---

- :bdg-success:`API` The path given to the ``memory`` argument of object now have their "~" expanded to the homedir.

- :bdg-success:`API` Display object created by plotting now uniformly expose an ``add_markers`` method.

- :bdg-success:`API` New function :func:`~image.resample_to_img` to resample one image on another one (just resampling / interpolation, no coregistration).

- :bdg-info:`Plotting` Function :func:`~plotting.plot_connectome` now plots connectome with colorbars.

Changes
-------

- :bdg-success:`API` Atlas fetcher :func:`~datasets.fetch_atlas_msdl` now returns directly labels of the regions in output variable ``labels`` and its coordinates in output variable ``region_coords`` and its type of network in ``networks``.

- :bdg-success:`API` The output variable name ``regions`` is now changed to ``maps`` in AAL atlas fetcher :func:`~datasets.fetch_atlas_aal`.

- :bdg-success:`API` AAL atlas now returns directly its labels in variable ``labels`` and its index values in variable ``indices``.
